@@ -1,21 +1,24 @@
 # Video::FourCC::Info
 #  Shows information about codecs specified as a Four Character Code
 #
-# $Id: Info.pm 8794 2009-08-29 13:21:43Z FREQUENCY@cpan.org $
+# $Id: Info.pm 5002 2009-01-20 04:35:47Z FREQUENCY@cpan.org $
+#
+# Copyright (C) 2009 by Jonathan Yu <frequency@cpan.org>
+#
+# This package is distributed with the same licensing terms as Perl itself.
+# For additional information, please read the included `LICENSE' file.
 
 package Video::FourCC::Info;
 
 use strict;
 use warnings;
 
-
 use Carp ();
 
 use DBI ();
-use DBD::SQLite ();
 
 use File::Basename ();
-use File::Spec ();
+use File::Spec     ();
 
 # Use DateTime if available
 eval { require DateTime; };
@@ -26,8 +29,7 @@ my $data = File::Spec->catfile(
   'codecs.dat'
 );
 
-# Since we are only going to read, this is okay; we can share
-# the dbhandle with different threads if need be
+# Since this is a 
 my $dbh = DBI->connect(
   'dbi:SQLite:dbname=' . $data,
   'notused', # cannot be null, or DBI complains
@@ -41,24 +43,24 @@ my $dbh = DBI->connect(
 
 =head1 NAME
 
-Video::FourCC::Info - Perl module to retrieve information about FourCCs
+Video::FourCC::Info - Find information about codecs specified as Four
+Character Code
 
 =head1 VERSION
 
-Version 1.004 ($Id: Info.pm 8794 2009-08-29 13:21:43Z FREQUENCY@cpan.org $)
+Version 1.1 ($Id: Info.pm 5002 2009-01-20 04:35:47Z FREQUENCY@cpan.org $)
 
 =cut
 
-our $VERSION = '1.004';
-$VERSION = eval $VERSION;
+use version; our $VERSION = qv('1.1');
 
 =head1 DESCRIPTION
 
-In order for video players to detect the algorithm required to decode a
-given video file, a four-byte sequence called a Four Character Code is
-written somewhere in the header of the file. This ensures that the detected
-codec format is independent of the file extension, which may be incorrect
-due to human error or for some other reason.
+In order for video players to detect the algorithm required to decode a given
+video file, a four-byte sequence called a Four Character Code is written
+somewhere in the header of the file. This ensures that the detected codec
+format is independent of the file extension, which may be incorrect due to
+human error or for some other reason.
 
 This is similar to the four-byte "magic number" used by the UNIX file(1)
 command to roughly determine a file format.
@@ -76,9 +78,9 @@ internally, your given FourCC's will be silently converted to uppercase.
 
 =head1 COMPATIBILITY
 
-This module was tested under Perl 5.10.0, using Debian Linux. However,
-because it's Pure Perl and doesn't do anything too obscure, it should be
-compatible with any version of Perl that supports its prerequisite modules.
+This module was tested under Perl 5.10.0, using Debian Linux. However, because
+it's Pure Perl and doesn't do anything too obscure, it should be compatible
+with any version of Perl that supports its prerequisite modules.
 
 If you encounter any problems on a different version or architecture, please
 contact the maintainer.
@@ -117,20 +119,17 @@ sub new {
 
   my $href = $sth->fetchrow_hashref;
   if (defined $href) {
-    $self->{desc}  = $href->{description};
-
+    if (defined $href->{description}) {
+      $self->{desc}  = $href->{description};
+    }
     if (defined $href->{owner}) {
       $self->{owner} = $href->{owner};
     }
     if (defined $href->{registered}) {
       # If we have a DateTime object, we should parse the date and store it
       if (exists $INC{'DateTime.pm'}) {
-        # Extract the Y/M/D numbers from $href->{registered}; this should
-        # have the format: yyyy-mm-dd
-        my ($year, $month, $day) =
-          ($href->{registered} =~ m/^(\d{4})-(\d{2})-(\d{2})$/s);
-
-          $self->{regdate} = DateTime->new(
+        my ($year, $month, $day) = split(/-/, $href->{registered});
+        $self->{regdate} = DateTime->new(
           year    => $year,
           month   => $month,
           day     => $day,
@@ -160,12 +159,12 @@ Example code:
   my $codec_desc = Video::FourCC::Info->describe('DIV3');
 
 Internally, this method creates a temporary object and returns the
-description, destroying the object due to falling out of scope. If you
-already have a C<Video::FourCC::Info> object, then the B<description>
-accessor will provide better performance.
+description, destroying the object due to falling out of scope. If you already
+have a C<Video::FourCC::Info> object, then the B<description> accessor will
+provide better performance.
 
-Note, that just like C<new>, this class method may throw an exception if
-the Four Character Code does not exist in the database.
+Note, that just like C<new>, this class method may throw an exception if the
+Four Character Code does not exist in the database.
 
 Remember that this value could be C<undef> if the information is unknown.
 
@@ -285,9 +284,9 @@ Your name here ;-)
 
 =over
 
-=item * Thanks to Allen Day E<lt>allenday@ucla.eduE<gt> and Benjamin R.
-Ginter E<lt>bginter@asicommunications.comE<gt>, developers of Video::Info,
-which inspired the creation of this module.
+=item * Thanks to Allen Day E<lt>allenday@ucla.eduE<gt> and Benjamin R. Ginter
+E<lt>bginter@asicommunications.comE<gt>, developers of Video::Info, which
+inspired the creation of this module.
 
 =back
 
@@ -325,13 +324,14 @@ L<http://cpants.perl.org/dist/overview/Video-FourCC-Info>
 
 =head1 FEEDBACK
 
-Please send relevant comments, rotten tomatoes and suggestions directly to
-the maintainer noted above.
+Please send relevant comments, rotten tomatoes and suggestions directly to the
+maintainer noted above.
 
 If you have a bug report or feature request, please file them on the CPAN
-Request Tracker at L<http://rt.cpan.org>. If you are able to submit your
-bug report in the form of failing unit tests, you are B<strongly> encouraged
-to do so.
+Request Tracker at L<http://rt.cpan.org>. If you are able to submit your bug
+report in the form of failing unit tests, you are B<strongly> encouraged to do
+so. Regular bug reports are always accepted and appreciated via the CPAN bug
+tracker.
 
 =head1 SEE ALSO
 
@@ -363,19 +363,39 @@ L<http://msdn.microsoft.com/en-us/library/ms867195.aspx#fourcccodes>
 
 =head1 LICENSE
 
-In a perfect world, I could just say that this package and all of the code
-it contains is Public Domain. It's a bit more complicated than that; you'll
-have to read the included F<LICENSE> file to get the full details.
+Copyright (C) 2009 by Jonathan Yu <frequency@cpan.org>
+
+This package is distributed under the same terms as Perl itself. At time of
+writing, this means that you are entitled to enjoy the covenants of, at your
+option:
+
+=over
+
+=item 1
+
+The Free Software Foundation's GNU General Public License (GPL), version 2 or
+later; or
+
+=item 2
+
+The Perl Foundation's Artistic License, version 2.0 or later
+
+=back
 
 =head1 DISCLAIMER OF WARRANTY
 
-The software is provided "AS IS", without warranty of any kind, express or
-implied, including but not limited to the warranties of merchantability,
-fitness for a particular purpose and noninfringement. In no event shall
-the authors or copyright holders be liable for any claim, damages or other
-liability, whether in an action of contract, tort or otherwise, arising
-from, out of or in connection with the software or the use or other dealings
-in the software.
+This software is provided by the copyright holders and contributors "AS IS"
+and ANY EXPRESS OR IMPLIED WARRANTIES, including, but not limited to, the
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+DISCLAIMED.
+
+In no event shall the copyright owner or contributors be liable for any
+direct, indirect, incidental, special, exemplary or consequential damages
+(including, but not limited to, procurement of substitute goods or services;
+loss of use, data or profits; or business interruption) however caused and on
+any theory of liability, whether in contract, strict liability or tort
+(including negligence or otherwise) arising in any way out of the use of this
+software, even if advised of the possibility of such damage.
 
 =cut
 
